c this is the main program for "integr" as described in
c   Section 7.3 of the UnkelScope Guide
c
c this declares the usual integers as *2 instead of *4
          implicit integer*2 (i-n)
c this declares the arrays storing the labels as character*1
       character*1 bpv1la,bph1la,bpt1la,
     $             bpv2la,bph2la,bpt2la,
     $             bpv3la,bph3la,bpt3la,
     $             bpv4la,bph4la,bpt4la,
     $             bhead1,bhead2
          parameter (n41=4096)
c this common holds the actual data for each of the traces.
      common/mdatf1/VERT1(n41),HORZ1(n41),TIME1(n41)
      common/mdatf2/VERT2(n41),HORZ2(n41),TIME2(n41)
      common/mdatf3/VERT3(n41),HORZ3(n41),TIME3(n41)
      common/mdatf4/VERT4(n41),HORZ4(n41),TIME4(n41)
c this common holds the number of channels and the number of
c      data points in each trace
          common/mdatan/nchd,npt1,npt2,npt3,npt4
c this common holds the labels for the traces
c      for example bpv1la is the label for vertical trace 1
          common/mdatal/
     $ bpv1la(20),bph1la(20),bpt1la(20),
     $ bpv2la(20),bph2la(20),bpt2la(20),
     $ bpv3la(20),bph3la(20),bpt3la(20),
     $ bpv4la(20),bph4la(20),bpt4la(20)
          common/mdatah/
     $ bhead1(40),bhead2(40)
c this common holds numbers used for input and output. DONOT change them
      common/munits/luset,ludis,lsio1,lsio2,lsio3,lsio4
c this common holds the names used to access the data files. DONOT change them
       common/mnames/bfinp(10),bfout(10)
c
c now starts the program
c
c setup initial values
        call init(1024)
c
7000    continue
c request and read the values of ball mass and radius
c
        write(*,6000)
c the $ at end of the format leaves cursor at the same line
6000    format(' Program to Solve for Motion of Dropped Ball'/)
701     continue
        write(*,600)
600     format(' Input Ball Mass (kg):',$)
        read(*,*)bmass
c check for reasonable mass
        if(bmass .gt. 0.0)go to 700
        write(*,601)
601     format(' Improper ball mass. Try again.')
        go to 701
700     continue
        write(*,602)
602     format(' Input Ball Radius (meters):',$)
        read(*,*)bradi
        if(bradi .gt. 0.0)go to 702
        write(*,6002)
6002    format(' Improper ball radius. Try again.')
        go to 700
702     continue
        write(*,6001)
6001    format(' Input Total Time (seconds):'$)
        read(*,*)tfinal
        if(tfinal .ge. 0.0)go to 7002
        write(*,6003)
6003    format(' Improper total time. Try again.')
        go to 702
7002    continue
c now compute the projected area of the ball
        area=3.14159*bradi*bradi
c now set the other parameters
        cdrag=1.2
        grav=9.81
        rhoair=1.17
c now compute the time step to be used
        dtime=tfinal/1024
c get input and output file names as needed
c       codes for nin and nout:
c         0 - dont want any
c         1 - binary file
c         2 - ascii file for transfer
c         3 - ascii file suitable for printing or porting to lotus etc.
c for this case set nin=0 because there is on input file
        nin = 0
c for this case set nout=1 to write binary file
        nout = 1
        call innout(nin,nout)
c if there is an input file open it and read the file
c       but with nin=0 nothing will be read
c
        if(nin .gt. 0)call binput(nin,maxch,maxlen,ner)
c
c now set the initial conditions
        posit=250.
        veloc=0.0
        time=0.0
c now the integration loop
        do 50 i=1,1024
c time
        time=time+dtime
c position
        posit=posit+veloc*dtime
c velocity - compute the acceleration
        accel=-grav+0.5*cdrag*rhoair*veloc*veloc*area/bmass
        veloc=veloc+accel*dtime
c now store the values into the data arrays
        vert1(i)=posit
        vert2(i)=veloc
        time1(i)=time
        time2(i)=time
c end of the loop
50      continue
c compute terminal velocity
        term=-sqrt(2.*bmass*grav/(cdrag*rhoair*area))
c now print final velocity and terminal velocity
        write(*,6006)posit,veloc,time,term
6006    format(' final position = ',1pe10.3,';final velocity = ',1pe10.3,
     $  ' at time = ',1pe10.3/
     $  ' computed terminal velocity = ',1pe10.3)
c now to get the labels set properly
c file
       call bstuf(40,bhead2,
     $   '   Ball Dropped From Tall Building      ')
c traces      length   array    quoted string
c
       call bstuf(20,bpv1la,'    Position(m)     ')
       call bstuf(20,bpv2la,'   Velocity(m/s)    ')
       call bstuf(20,bpt1la,'    Time(seconds)   ')
       call bstuf(20,bpt2la,'    Time(seconds)   ')
c set horizontal labels to garbage
       call bstuf(20,bph1la,'     GARBAGE        ')
       call bstuf(20,bph2la,'     GARBAGE        ')
c now set maximum traces to 2
       maxch=2
c set maximum number of points of trace 1 and 2
       npt1=1024
       npt2=1024
c set largest length of the traces
       maxlen=1024
c
c if there is an output file, open it and write the file
c    nout=1 means that a binary file will be written
        if(nout .gt. 0)call boutpu(nout,maxch,maxlen,ner)
c
c program stops
        stop
        end
